@@ -6,7 +6,7 @@ import json
 def display(doc):
     if isinstance(doc, (coreapi.Document, coreapi.Error, coreapi.Object, coreapi.Array, coreapi.Link)):
         codec = coreapi.codecs.DisplayCodec()
-        return codec.dump(doc, colorize=True)
+        return codec.encode(doc, colorize=True)
 
     if doc is None:
         return ''
